.. _head_pose.yawning:

Yawning Detection
=================

.. automodule:: eyetrace.head_pose.yawning
   :members:
   :undoc-members:
   :show-inheritance:

Detects yawns by thresholding the MAR signal over time. Provides functions to
identify yawn intervals and compute yawn frequency.